@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010, 2011, 2012 Sebastian Wiesner <lunaryorn@gmail.com>
+# Copyright (C) 2010, 2011, 2012, 2013 Sebastian Wiesner <lunaryorn@gmail.com>
 
 # This library is free software; you can redistribute it and/or modify it
 # under the terms of the GNU Lesser General Public License as published by the
@@ -68,8 +68,11 @@ class Mock(object):
 
 # mock out native modules used throughout pyudev to enable Sphinx autodoc even
 # if these modules are unavailable, as on readthedocs.org
-Mock.mock_modules('PyQt4', 'PyQt4.QtCore', 'PySide', 'PySide.QtCore',
-                  'glib', 'gobject', 'wx', 'wx.lib', 'wx.lib.newevent',
+Mock.mock_modules('PyQt5', 'PyQt5.QtCore',
+                  'PyQt4', 'PyQt4.QtCore',
+                  'PySide', 'PySide.QtCore',
+                  'glib', 'gobject',
+                  'wx', 'wx.lib', 'wx.lib.newevent',
                   'pyudev._libudev')
 
 
@@ -86,7 +89,7 @@ import pyudev
 needs_sphinx = '1.0'
 
 extensions = ['sphinx.ext.autodoc', 'sphinx.ext.autosummary',
-              'sphinx.ext.intersphinx', 'sphinxcontrib.issuetracker']
+              'sphinx.ext.intersphinx']
 
 master_doc = 'index'
 exclude_patterns = ['_build/*']
@@ -98,17 +101,13 @@ version = '.'.join(pyudev.__version__.split('.')[:2])
 release = pyudev.__version__
 
 templates_path = ['_templates']
-html_theme = 'default'
+html_theme = 'classic'
 html_static_path = []
 html_sidebars = {'**': ['info.html', 'localtoc.html', 'relations.html',
                         'sourcelink.html']}
 
 intersphinx_mapping = {'python': ('http://docs.python.org/', None),
-                       'pytest': ('http://pytest.org/latest', None),
-                       'pyside': ('http://www.pyside.org/docs/pyside/', None)}
-
-issuetracker = 'github'
-issuetracker_project = 'lunaryorn/pyudev'
+                       'pytest': ('http://pytest.org/latest', None)}
 
 
 class UDevVersion(Directive):
