@@ -32,7 +32,6 @@ import operator
 import gc
 from datetime import timedelta
 
-from hypothesis import assume
 from hypothesis import given
 from hypothesis import settings
 from hypothesis import strategies
@@ -64,11 +63,8 @@ class TestDevice(object):
         assert a_device.parent is None or \
            isinstance(a_device.parent, Device)
 
-    _devices = [d for d in _DEVICES if d.parent]
-    @pytest.mark.skipif(
-        len(_devices) == 0,
-        reason='no device with a parent'
-    )
+    _devices = [d for d in _DEVICES if d.parent is not None]
+    @pytest.mark.skipif(len(_devices) == 0, reason='no device with a parent')
     @_UDEV_TEST(172, "test_child_of_parents")
     @given(strategies.sampled_from(_devices))
     @settings(max_examples=5, min_satisfying_examples=1)
@@ -76,10 +72,7 @@ class TestDevice(object):
         assert a_device in a_device.parent.children
 
     _devices = [d for d in _DEVICES if list(d.children)]
-    @pytest.mark.skipif(
-        len(_devices) == 0,
-        reason='no device with a child'
-    )
+    @pytest.mark.skipif(len(_devices) == 0, reason='no device with a child')
     @_UDEV_TEST(172, "test_children")
     @given(strategies.sampled_from(_devices))
     @settings(max_examples=5, min_satisfying_examples=1)
@@ -97,7 +90,7 @@ class TestDevice(object):
             assert ancestor == child.parent
             child = ancestor
 
-    _devices = [d for d in _DEVICES if d.find_parent(d.subsystem)]
+    _devices = [d for d in _DEVICES if d.find_parent(d.subsystem) is not None]
     @pytest.mark.skipif(
         len(_devices) == 0,
         reason='no device with a parent in the same subsystem'
@@ -336,25 +329,47 @@ class TestDevice(object):
     @settings(max_examples=5)
     def test_iteration(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
-        for property in device:
-            assert is_unicode_string(property)
+        for prop in device.properties:
+            assert is_unicode_string(prop)
         # test that iteration really yields all properties
-        device_properties = set(device)
-        for property in device_datum.properties:
-            assert property in device_properties
+        device_properties = set(device.properties)
+        for prop in device_datum.properties:
+            assert prop in device_properties
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
-    @settings(max_examples=5)
+    @settings(max_examples=100)
+    @_UDEV_TEST(230, "check exact equivalence of device_datum and device")
     def test_length(self, a_context, device_datum):
+        """
+        Verify that the keys in the device and in the datum are equal.
+        """
         device = Devices.from_path(a_context, device_datum.device_path)
-        assert len(device) == len(device_datum.properties)
+        assert frozenset(device_datum.properties.keys()) == \
+           frozenset(device.properties.keys())
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
-    @settings(max_examples=5)
+    @settings(max_examples=100)
+    def test_key_subset(self, a_context, device_datum):
+        """
+        Verify that the device contains all the keys in the device datum.
+        """
+        device = Devices.from_path(a_context, device_datum.device_path)
+        assert frozenset(device_datum.properties.keys()) <= \
+           frozenset(device.properties.keys())
+
+    @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
+    @settings(max_examples=100)
     def test_getitem(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
         for prop in device_datum.properties:
-            assert device[prop] == device_datum.properties[prop]
+            if prop == 'DEVLINKS':
+                assert sorted(device.properties[prop].split(),) == \
+                   sorted(device_datum.properties[prop].split(),)
+            elif prop == 'TAGS':
+                assert sorted(device.properties[prop].split(':'),) == \
+                   sorted(device_datum.properties[prop].split(':'),)
+            else:
+                assert device.properties[prop] == device_datum.properties[prop]
 
     _device_data = [d for d in _DEVICE_DATA if 'DEVNAME' in d.properties]
     @pytest.mark.skipif(
@@ -367,7 +382,8 @@ class TestDevice(object):
         device = Devices.from_path(a_context, device_datum.device_path)
         data_devname = os.path.join(
             a_context.device_path, device_datum.properties['DEVNAME'])
-        device_devname = os.path.join(a_context.device_path, device['DEVNAME'])
+        device_devname = \
+           os.path.join(a_context.device_path, device.properties['DEVNAME'])
         assert device_devname == data_devname
 
     @given(strategies.sampled_from(_DEVICES))
@@ -375,36 +391,41 @@ class TestDevice(object):
     def test_getitem_nonexisting(self, a_device):
         with pytest.raises(KeyError) as excinfo:
             # pylint: disable=pointless-statement
-            a_device['a non-existing property']
+            a_device.properties['a non-existing property']
         assert str(excinfo.value) == repr('a non-existing property')
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
     @settings(max_examples=5)
     def test_asint(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
-        for property, value in device_datum.properties.items():
+        for prop, value in device_datum.properties.items():
             try:
                 value = int(value)
             except ValueError:
                 with pytest.raises(ValueError):
-                    device.asint(property)
+                    device.properties.asint(prop)
             else:
-                assert device.asint(property) == value
+                assert device.properties.asint(prop) == value
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
     @settings(max_examples=5)
     def test_asbool(self, a_context, device_datum):
+        """
+        Test that values of 1 and 0 get properly interpreted as bool
+        and that all other values raise a ValueError.
+
+        :param Context a_context: libudev context
+        :param device_datum: a device datum
+        """
         device = Devices.from_path(a_context, device_datum.device_path)
         for prop, value in device_datum.properties.items():
             if value == '1':
-                assert device.asbool(prop)
+                assert device.properties.asbool(prop)
             elif value == '0':
-                assert not device.asbool(prop)
+                assert not device.properties.asbool(prop)
             else:
                 with pytest.raises(ValueError) as exc_info:
-                    device.asbool(prop)
-                message = 'Not a boolean value: {0!r}'
-                assert str(exc_info.value) == message.format(value)
+                    device.properties.asbool(prop)
 
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
@@ -446,7 +467,8 @@ class TestDevice(object):
     _devices = [
        d for d in _DEVICES if \
           d.device_type == 'disk' and \
-          'ID_WWN_WITH_EXTENSION' in d and 'DM_MULTIPATH_TIMESTAMP' not in d
+          'ID_WWN_WITH_EXTENSION' in d.properties and \
+          'DM_MULTIPATH_TIMESTAMP' not in d.properties
     ]
     @pytest.mark.skipif(
         len(_devices) == 0,
@@ -464,7 +486,7 @@ class TestDevice(object):
         Skip any multipathed paths, see:
         https://bugzilla.redhat.com/show_bug.cgi?id=1263441.
         """
-        id_wwn = a_device['ID_WWN_WITH_EXTENSION']
+        id_wwn = a_device.properties['ID_WWN_WITH_EXTENSION']
         assert a_device.subsystem == u'block'
 
         id_path = '/dev/disk/by-id'
